@@ -20,8 +20,8 @@ class locustFrameProcessor(batchRunner.frameProcessor):
 
     def frameCmd( self, frameNum ):
         usersPerWorker = 6  # number of simulated users per worker instance
-        rampUpRate = 1  # number of simulated users to spawn per second (can be fractional)
-        duration = 60  # number of seconds to run the test (must be integer)
+        rampUpRate = .133  # number of simulated users to spawn per second (can be fractional)
+        duration = 90  # number of seconds to run the test (must be integer)
         csvSpec = '--csv ~/worker_%03d' % frameNum
         cmd = 'cd locustWorker && python3 -u ./runLocustWorker.py --host=https://loadtest-target.neocortix.com %s --only-summary --exit-code-on-error 0 --no-web -c %d -r %f --run-time %d' % (
             csvSpec, usersPerWorker, rampUpRate, duration
