@@ -12,13 +12,14 @@ import os
 import signal
 import sys
 import random
+import subprocess
 import time
 import uuid
 
 # third-party modules
 import requests
 
-__version__ = '0.12.16'
+__version__ = '1.1.0'
 logger = logging.getLogger(__name__)
 
 
@@ -449,6 +450,22 @@ def launchScInstances( authToken, encryptFiles, numReq=1,
         terminateJobInstances( authToken, jobId )
         raise
 
+def purgeKnownHost( host, port ):
+    # purge an entry from known_hosts
+    cmd = 'ssh-keygen -q -R [%s]:%s > /dev/null 2> /dev/null' % (host, port )
+    #logger.debug( 'cmd: %s', cmd )
+    retCode = subprocess.call( cmd, shell=True )
+    if retCode != 0:
+        logger.error( 'returnd error code %s', retCode )
+
+def purgeKnownHosts( inRecs ):
+    for inRec in inRecs:
+        if 'ssh' in inRec:
+            host = inRec['ssh'].get('host')
+            port = inRec['ssh'].get('port')
+            if host and port:
+                purgeKnownHost( host, port )
+
 def terminateNcscInstance( authToken, iid, maxRetries=1000 ):
     headers = ncscReqHeaders( authToken )
     url = 'https://cloud.neocortix.com/cloud-api/sc/instances/' + iid
